@@ -37,6 +37,7 @@
 
 #include "gamewidget.h"
 #include "settings.h"
+#include "backgroundselector.h"
 
 KBounceMainWindow::KBounceMainWindow()
 {
@@ -83,6 +84,12 @@ void KBounceMainWindow::initXMLUI()
     KStandardGameAction::highscores(this, SLOT(showHighscore()), actionCollection());
     KStandardGameAction::quit(this, SLOT(close()), actionCollection());
   
+    // Difficulty
+    KGameDifficulty::init(this, m_gameWidget, SLOT(levelChanged(KGameDifficulty::standardLevel)));
+    KGameDifficulty::addStandardLevel(KGameDifficulty::Easy);
+    KGameDifficulty::addStandardLevel(KGameDifficulty::Medium);
+    KGameDifficulty::addStandardLevel(KGameDifficulty::Hard);
+
     // Settings
     KStandardAction::preferences( this, SLOT( configureSettings() ), actionCollection() );
     m_soundAction = new KToggleAction( i18n("&Play Sounds"), this );
@@ -90,54 +97,55 @@ void KBounceMainWindow::initXMLUI()
     connect( m_soundAction, SIGNAL( triggered( bool ) ), this, SLOT( setSounds( bool ) ) );
 }
 
+		   
+		   
 void KBounceMainWindow::newGame()
 {
-    // Check for running game
+	// Check for running game
     closeGame();
-    if ( m_gameWidget->state() == KBounceGameWidget::BeforeFirstGame || m_gameWidget->state() == KBounceGameWidget::GameOver )
-    {
-	m_gameWidget->newGame();
-    }
+	if ( m_gameWidget->state() == KBounceGameWidget::BeforeFirstGame || m_gameWidget->state() == KBounceGameWidget::GameOver )
+	{
+		m_gameWidget->newGame();
+	}
 }
 
 void KBounceMainWindow::pauseGame()
 {
-    if ( m_gameWidget->state() == KBounceGameWidget::Paused )
-    {
-	m_gameWidget->setPaused( false );
-    }
+	if ( m_gameWidget->state() == KBounceGameWidget::Paused )
+	{
+		m_gameWidget->setPaused( false );
+	}
     else
-    {
-	m_gameWidget->setPaused( true );
-    }
+	{
+		m_gameWidget->setPaused( true );
+	}
 }
 
 void KBounceMainWindow::closeGame()
 {
-    if ( m_gameWidget->state() == KBounceGameWidget::BeforeFirstGame || m_gameWidget->state() == KBounceGameWidget::GameOver )
-    {
-	return;
-    }
+	if ( m_gameWidget->state() == KBounceGameWidget::BeforeFirstGame || m_gameWidget->state() == KBounceGameWidget::GameOver )
+	{
+		return;
+	}
 
-    KBounceGameWidget::State old_state = m_gameWidget->state();
-    if ( old_state == KBounceGameWidget::Running )
-	m_gameWidget->setPaused( true );
-    int ret = KMessageBox::questionYesNo( this, i18n( "Do you really want to close the running game?" ), QString(),
-	    KStandardGuiItem::close(), KStandardGuiItem::cancel() );
-    if ( ret == KMessageBox::Yes )
-    {
-	m_gameWidget->closeGame();
-    }
-    else if ( old_state == KBounceGameWidget::Running )
-    {
-	m_gameWidget->setPaused( false );
-    }
+	KBounceGameWidget::State old_state = m_gameWidget->state();
+	if ( old_state == KBounceGameWidget::Running )
+		m_gameWidget->setPaused( true );
+	int ret = KMessageBox::questionYesNo( this, i18n( "Do you really want to close the running game?" ), QString(),  KStandardGuiItem::close(), KStandardGuiItem::cancel() );
+	if ( ret == KMessageBox::Yes )
+	{
+		m_gameWidget->closeGame();
+	}
+	else if ( old_state == KBounceGameWidget::Running )
+	{
+		m_gameWidget->setPaused( false );
+	}
 }
 
 void KBounceMainWindow::gameOverNow()
 {
-    statusBar()->showMessage(  i18n("Game over. Press <Space> for a new game") );
-    highscore();
+	statusBar()->showMessage(  i18n("Game over. Click to start a game") );
+	highscore();
 }
 
 /**
@@ -145,15 +153,20 @@ void KBounceMainWindow::gameOverNow()
  */
 void KBounceMainWindow::showHighscore()
 {
-    KScoreDialog ksdialog( KScoreDialog::Name | KScoreDialog::Score | KScoreDialog::Level, this );
-    ksdialog.exec();
+	KScoreDialog ksdialog( KScoreDialog::Name | KScoreDialog::Score, this );
+	ksdialog.addLocalizedConfigGroupNames(KGameDifficulty::localizedLevelStrings());
+	ksdialog.setConfigGroupWeights(KGameDifficulty::levelWeights());
+	ksdialog.setConfigGroup(KGameDifficulty::localizedLevelString());
+	ksdialog.exec();
 }
 
 void KBounceMainWindow::highscore()
 {
     kDebug() ;
     KScoreDialog ksdialog( KScoreDialog::Name | KScoreDialog::Score | KScoreDialog::Level, this );
-
+    ksdialog.addLocalizedConfigGroupNames(KGameDifficulty::localizedLevelStrings());
+    ksdialog.setConfigGroupWeights(KGameDifficulty::levelWeights());
+    ksdialog.setConfigGroup(KGameDifficulty::localizedLevelString());
     KScoreDialog::FieldInfo info;
     info[KScoreDialog::Score].setNum( m_gameWidget->score() );
     info[KScoreDialog::Level].setNum( m_gameWidget->level() );
@@ -167,6 +180,7 @@ void KBounceMainWindow::configureSettings()
 
     KConfigDialog* dialog = new KConfigDialog( this, "settings", KBounceSettings::self());
     dialog->addPage( new KGameThemeSelector( dialog, KBounceSettings::self(), KGameThemeSelector::NewStuffDisableDownload ), i18n( "Theme" ), "games-config-theme" );
+    dialog->addPage( new BackgroundSelector(dialog,KBounceSettings::self() ),i18n("Background"),"games-config-background");
     dialog->setHelp(QString(),"kbounce");
     dialog->show();
     connect( dialog, SIGNAL( settingsChanged( const QString& ) ), this, SLOT( settingsChanged() ) );
@@ -174,14 +188,15 @@ void KBounceMainWindow::configureSettings()
 
 void KBounceMainWindow::readSettings()
 {
+    KGameDifficulty::setLevel((KGameDifficulty::standardLevel)KBounceSettings::level());
     m_soundAction->setChecked( KBounceSettings::playSounds() );
-    settingsChanged();
+	m_gameWidget->settingsChanged();
 }
 
 void KBounceMainWindow::settingsChanged()
 {
     m_gameWidget->settingsChanged();
-	KBounceSettings::self()->writeConfig(); // Bug 184606
+    KBounceSettings::self()->writeConfig(); // Bug 184606
 }
 
 void KBounceMainWindow::setSounds( bool val )
@@ -219,31 +234,27 @@ void KBounceMainWindow::gameStateChanged( KBounceGameWidget::State state )
 {
     switch ( state )
     {
-	case KBounceGameWidget::Paused :
-	    m_pauseAction->setChecked( true );
-	    m_statusBar->clearMessage();
-	    break;
-	case KBounceGameWidget::Running :
-	    m_pauseAction->setChecked( false );
-	    m_statusBar->clearMessage();
-	    break;
-	case KBounceGameWidget::GameOver :
-	    statusBar()->showMessage(  i18n("Game over. Press <Space> for a new game") );
-	    highscore(); 
-	    break;
-    }
-/*
-    if ( state == KBounceGameWidget::Paused )
-    {
-	m_pauseButton->setChecked( true );
-        m_statusBar->clearMessage();
-    }
-    if ( state == KBounceGameWidget::Running )
-    {
-	m_pauseButton->setChecked( false );
-        m_statusBar->clearMessage();
-    }
-    */
+		case KBounceGameWidget::BeforeFirstGame :
+			break;
+		case KBounceGameWidget::BetweenLevels :
+			break;
+		case KBounceGameWidget::Suspended :
+			break;
+		case KBounceGameWidget::Paused :
+		    m_pauseAction->setChecked( true );
+		    m_statusBar->clearMessage();
+		    break;
+		case KBounceGameWidget::Running :
+		    KGameDifficulty::setEnabled( false );
+		    m_pauseAction->setChecked( false );
+		    m_statusBar->clearMessage();
+		    break;
+		case KBounceGameWidget::GameOver :
+		    statusBar()->showMessage(  i18n("Game over. Click to start a game") );
+		    highscore();
+		    KGameDifficulty::setEnabled(true);
+		    break;
+	    }
 }
 
 void KBounceMainWindow::focusOutEvent( QFocusEvent *ev )
@@ -315,7 +326,4 @@ i18n("On to level %1. Remember you get %2 lives this time!", m_game.level+1, m_g
 // }
 
 
-
-
-
 #include "mainwindow.moc"
