@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2008 Stefan Majewsky <majewsky.stefan@ages-skripte.org>
+ *   Copyright 2008-2009 Stefan Majewsky <majewsky.stefan@ages-skripte.org>
  *
  *   This program is free software; you can redistribute it and/or
  *   modify it under the terms of the GNU General Public
@@ -30,7 +30,8 @@ namespace KDiamond
 	//registered colors of diamonds
 	enum Color
 	{
-		Selection = 0, //that is actually no diamond type, but gives the chance to reuse the Diamond class' code for the selection marker
+		NoColor = -1,  //use this if no actual color can be named (e.g. for a null Diamond pointer)
+		Selection = 0, //actually no diamond type, but this allows to reuse the Diamond class' code for the selection marker
 		RedDiamond = 1,
 		GreenDiamond,
 		BlueDiamond,
@@ -45,7 +46,7 @@ class Diamond : public QObject, public QGraphicsPixmapItem
 {
 	Q_OBJECT
 	public:
-		Diamond(int xIndex, int yIndex, int xPos, int yPos, KDiamond::Color color, Board *board);
+		Diamond(int xPos, int yPos, KDiamond::Color color, Board *board);
 
 		KDiamond::Color color() const;
 		int xIndex() const;
@@ -65,7 +66,7 @@ class Diamond : public QObject, public QGraphicsPixmapItem
 
 		KDiamond::Color m_color;
 		int m_xIndex, m_yIndex; //the index of the diamond in the Board's internal array (used for communication with Board)
-		QPointF m_pos, m_target; //current position of diamond in board coordinates (see Board::boardToScene for details)
+		QPointF m_pos;
 		bool m_mouseDown;
 		QPointF m_mouseDownPos; //position of last mouse-down event in diamond coordinates
 };
