@@ -48,6 +48,7 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 	setCaption(i18n("New Game"));
 	setButtons(Ok | Cancel);
 	setDefaultButton(Ok);
+	setMinimumSize(640,310);
         connect(this, SIGNAL(okClicked()), this, SLOT(slotOk()));
 
 	setFaceType(KPageDialog::Tree);
@@ -118,12 +119,12 @@ NewGameDialog::NewGameDialog(bool enableCourses)
 		externCourses = configGroup.readEntry("extra",QStringList());
 
 		/// course loading
-		QStringList items = externCourses + KGlobal::dirs()->findAllResources("appdata", "courses/*");
+		const QStringList items = externCourses + KGlobal::dirs()->findAllResources("appdata", "courses/*");
 		QStringList nameList;
 		const QString lastCourse(configGroup.readEntry("course", ""));
 		int curItem = 0;
 		i = 0;
-		for (QStringList::Iterator it = items.begin(); it != items.end(); ++it, ++i)
+		for (QStringList::const_iterator it = items.begin(); it != items.end(); ++it, ++i)
 		{
 			QString file = *it;
 			CourseInfo curinfo;
@@ -286,12 +287,12 @@ void NewGameDialog::selectionChanged()
 
 void NewGameDialog::addCourse()
 {
-	QStringList files = KFileDialog::getOpenFileNames( KUrl("kfiledialog:///kourses"),
+	const QStringList files = KFileDialog::getOpenFileNames( KUrl("kfiledialog:///kourses"),
 			 QString::fromLatin1("application/x-kourse"), this, i18n("Pick Kolf Course"));
 
 	bool hasDuplicates = false;
 
-	for (QStringList::Iterator fileIt = files.begin(); fileIt != files.end(); ++fileIt)
+	for (QStringList::const_iterator fileIt = files.begin(); fileIt != files.end(); ++fileIt)
 	{
 		if (names.contains(*fileIt) > 0)
 		{
